@@ -7,9 +7,9 @@ SERVICE = 'sync'
 
 class UserReadContract(Contract):
     id = serializers.IntegerField(min_value=1)
-    last_login = serializers.DateTimeField()
+    last_login = serializers.DateTimeField(allow_null=True)
     username = serializers.CharField()
-    email = serializers.EmailField(allow_null=True)
+    email = serializers.EmailField(allow_blank=True)
     date_joined = serializers.DateTimeField()
 
 
